# CreateInboxFileRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**virtual_directory** | **str** | Directory name used for tagging the uploaded file | 
**blob_file_token** | **str** | Token representing the uploaded file | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


